.. _spkg_cibuildwheel:

cibuildwheel: Build Python wheels on CI with minimal configuration
============================================================================

Description
-----------

Build Python wheels on CI with minimal configuration

License
-------

Upstream Contact
----------------

https://pypi.org/project/cibuildwheel/


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_certifi`
- :ref:`spkg_filelock`
- :ref:`spkg_packaging`
- :ref:`spkg_platformdirs`

Version Information
-------------------

requirements.txt::

    cibuildwheel==2.23.3


Equivalent System Packages
--------------------------

(none known)

